django_analyses.serializers package — django_analyses 0.0.3 documentation

# django_analyses.serializers package

## Subpackages

- django_analyses.serializers.input package
  - Subpackages
    - django_analyses.serializers.input.definitions package
      - Submodules
      - django_analyses.serializers.input.definitions.boolean_input_definition module
      - django_analyses.serializers.input.definitions.directory_input_definition module
      - django_analyses.serializers.input.definitions.file_input_definition module
      - django_analyses.serializers.input.definitions.float_input_definition module
      - django_analyses.serializers.input.definitions.input_definition module
      - django_analyses.serializers.input.definitions.integer_input_definition module
      - django_analyses.serializers.input.definitions.list_input_definition module
      - django_analyses.serializers.input.definitions.string_input_definition module
      - Module contents
    - django_analyses.serializers.input.types package
      - Submodules
      - django_analyses.serializers.input.types.boolean_input module
      - django_analyses.serializers.input.types.directory_input module
      - django_analyses.serializers.input.types.file_input module
      - django_analyses.serializers.input.types.float_input module
      - django_analyses.serializers.input.types.integer_input module
      - django_analyses.serializers.input.types.list_input module
      - django_analyses.serializers.input.types.string_input module
      - Module contents
  - Submodules
  - django_analyses.serializers.input.input module
  - django_analyses.serializers.input.input_specification module
  - Module contents
- django_analyses.serializers.output package
  - Subpackages
    - django_analyses.serializers.output.definitions package
      - Submodules
      - django_analyses.serializers.output.definitions.file_output_definition module
      - django_analyses.serializers.output.definitions.output_definition module
      - Module contents
    - django_analyses.serializers.output.types package
      - Submodules
      - django_analyses.serializers.output.types.file_output module
      - Module contents
  - Submodules
  - django_analyses.serializers.output.output module
  - django_analyses.serializers.output.output_specification module
  - Module contents
- django_analyses.serializers.pipeline package
  - Submodules
  - django_analyses.serializers.pipeline.node module
  - django_analyses.serializers.pipeline.pipe module
  - django_analyses.serializers.pipeline.pipeline module
  - Module contents
- django_analyses.serializers.utils package
  - Submodules
  - django_analyses.serializers.utils.polymorphic module
  - Module contents

## Submodules

## django_analyses.serializers.analysis module

class `django_analyses.serializers.analysis.` `AnalysisSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'title', 'description', 'category', 'created', 'modified', 'url')
    `model`

      alias of `django_analyses.models.analysis.Analysis`

## django_analyses.serializers.analysis_version module

class `django_analyses.serializers.analysis_version.` `AnalysisVersionSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'analysis', 'title', 'description', 'input_specification', 'output_specification', 'created', 'modified', 'url')
    `model`

      alias of `django_analyses.models.analysis_version.AnalysisVersion`

## django_analyses.serializers.category module

class `django_analyses.serializers.category.` `CategorySerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'title', 'description', 'created', 'modified', 'parent', 'subcategories', 'url')
    `model`

      alias of `django_analyses.models.category.Category`

## django_analyses.serializers.run module

class `django_analyses.serializers.run.` `RunSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.HyperlinkedModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'user', 'analysis_version', 'input_set', 'output_set', 'created', 'modified', 'url')
    `model`

      alias of `django_analyses.models.run.Run`

## Module contents